==> google-cloud-sdk-312.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/kuberun/devkits/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to list available Kuberun Development Kits."""
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.kuberun import flags
from googlecloudsdk.command_lib.kuberun import kuberun_command
from googlecloudsdk.core import log

_DETAILED_HELP = {
    'EXAMPLES':
        """
        To show all available Development Kits, run:

            $ {command}
        """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class List(kuberun_command.KubeRunCommandWithOutput, base.ListCommand):
  """Lists available Development Kits."""

  detailed_help = _DETAILED_HELP

  # TODO(b/169182315): remove this method
  @staticmethod
  def AddTemporaryArgs(parser):
    flags.AddNamespaceFlag(parser)

  @staticmethod
  def Args(parser):
    base.URI_FLAG.RemoveFromParser(parser)
    List.AddTemporaryArgs(parser)

  def BuildKubeRunArgs(self, args):
    return []

  def Command(self):
    return ['devkits', 'list']

  def FormatOutput(self, out, args):
    # TODO(b/169186627): handle this as JSON
    return out

  # TODO(b/169186627): remove this workaround
  def Display(self, args, output):
    log.out.write(output)

==> google-cloud-sdk-313.0.1-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/kuberun/devkits/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to list available Kuberun Development Kits."""
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.kuberun import kuberun_command
from googlecloudsdk.core import log

_DETAILED_HELP = {
    'EXAMPLES':
        """
        To show all available Development Kits, run:

            $ {command}
        """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class List(kuberun_command.KubeRunCommandWithOutput, base.ListCommand):
  """Lists available Development Kits."""

  detailed_help = _DETAILED_HELP
  flags = []

  @classmethod
  def Args(cls, parser):
    super(List, cls).Args(parser)
    base.URI_FLAG.RemoveFromParser(parser)

  def Command(self):
    return ['devkits', 'list']

  def FormatOutput(self, out, args):
    # TODO(b/169186627): handle this as JSON
    return out

  # TODO(b/169186627): remove this workaround
  def Display(self, args, output):
    log.out.write(output)
